==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/BuildConfigListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface BuildConfigListFluent<A extends BuildConfigListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,BuildConfig item);
    public A setToItems(int index,BuildConfig item);
    public A addToItems(BuildConfig... items);
    public A addAllToItems(Collection<BuildConfig> items);
    public A removeFromItems(BuildConfig... items);
    public A removeAllFromItems(Collection<BuildConfig> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<BuildConfigBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<BuildConfig> getItems();
    public List<BuildConfig> buildItems();
    public BuildConfig buildItem(int index);
    public BuildConfig buildFirstItem();
    public BuildConfig buildLastItem();
    public BuildConfig buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<BuildConfigBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<BuildConfigBuilder> predicate);
    public A withItems(List<BuildConfig> items);
    public A withItems(BuildConfig... items);
    public Boolean hasItems();
    public BuildConfigListFluent.ItemsNested<A> addNewItem();
    public BuildConfigListFluent.ItemsNested<A> addNewItemLike(BuildConfig item);
    public BuildConfigListFluent.ItemsNested<A> setNewItemLike(int index,BuildConfig item);
    public BuildConfigListFluent.ItemsNested<A> editItem(int index);
    public BuildConfigListFluent.ItemsNested<A> editFirstItem();
    public BuildConfigListFluent.ItemsNested<A> editLastItem();
    public BuildConfigListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<BuildConfigBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildConfigFluent<BuildConfigListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/BuildConfigListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface BuildConfigListFluent<A extends BuildConfigListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,BuildConfig item);
    public A setToItems(int index,BuildConfig item);
    public A addToItems(BuildConfig... items);
    public A addAllToItems(Collection<BuildConfig> items);
    public A removeFromItems(BuildConfig... items);
    public A removeAllFromItems(Collection<BuildConfig> items);
    public A removeMatchingFromItems(Predicate<BuildConfigBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<BuildConfig> getItems();
    public List<BuildConfig> buildItems();
    public BuildConfig buildItem(int index);
    public BuildConfig buildFirstItem();
    public BuildConfig buildLastItem();
    public BuildConfig buildMatchingItem(Predicate<BuildConfigBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<BuildConfigBuilder> predicate);
    public A withItems(List<BuildConfig> items);
    public A withItems(BuildConfig... items);
    public Boolean hasItems();
    public BuildConfigListFluent.ItemsNested<A> addNewItem();
    public BuildConfigListFluent.ItemsNested<A> addNewItemLike(BuildConfig item);
    public BuildConfigListFluent.ItemsNested<A> setNewItemLike(int index,BuildConfig item);
    public BuildConfigListFluent.ItemsNested<A> editItem(int index);
    public BuildConfigListFluent.ItemsNested<A> editFirstItem();
    public BuildConfigListFluent.ItemsNested<A> editLastItem();
    public BuildConfigListFluent.ItemsNested<A> editMatchingItem(Predicate<BuildConfigBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BuildConfigFluent<BuildConfigListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
